# API Logic Project - `venv` Setup 

Once you use `ApiLogicServer` to create your project, you need to create the `venv` Python environment (unless you are using the Docker version of API Logic Server).

## Create the `venv'

Proceed as described in the [API Logic Server Readme](https://github.com/valhuber/ApiLogicServer/blob/main/README.md#installation).  This contains the latest information.

You may find the command line scripts in this folder helpful to save typing.  
  
  * The `.ps1` version is for Windows PowerShell
  * The `-linux` version has been tested for Ubuntu, and
  * The `venv.sh` has been tested on the Mac.

## Verify the `venv'

Optionally, you can check your Python environment by running:
```
Python py.py
```
